Module client_credentials

Module client_credentials 

Structs

ClientAuthorizationRequest
ClientAuthorizationResponse
ClientCredentials

Statics

REQUEST_SERVICE_TOKEN_CACHED
Cached static for the request_service_token_cached function.

Functions

request_service_token
request_service_token_cached
This is a cached function that uses the REQUEST_SERVICE_TOKEN_CACHED cached static.
request_service_token_cached_no_cache
Origin of the cached function request_service_token_cached.
request_service_token_cached_prime_cache
Primes the cached function request_service_token_cached. This is a cached function that uses the REQUEST_SERVICE_TOKEN_CACHED cached static.