Module secure

Module secure 

Functions

decrypt_rsa_private_key
generate_rsa_key_pair
Generate a new RSA key pair and return the private key as a PEM string. The password is used to encrypt the private key and is required to decrypt it.
generate_secure_string